@@ -5,3 +5,15 @@
 
 DEFAULT_ENDPOINT = 'https://api.connect.cloudblue.com/public/v1'
 DEFAULT_USER_AGENT = 'CloudBlue Connect CLI/'
+
+REPORT_PARAM_TYPES = [
+    'date_range',
+    'date',
+    'product',
+    'marketplace',
+    'hub',
+    'checkbox',
+    'choice',
+    'single_line',
+    'object',
+]
